require 'yaml'
require 'socket'

require_relative 'reservations/version'
require_relative 'reservations/batch'
require_relative 'reservations/reservation'
require_relative 'reservations/node'
require_relative 'reservations/query'

# The namespace used for OSC gems.
module OSC
  # The main namespace for OSC::Reservations. Provides the ability to submit
  # and read back reservations to the local batch scheduler.
  module Reservations
      # Path to batch server configuration file.
      CONFIG_ROOT = File.expand_path("../../../config", __FILE__)

      # Default path to the batch config yaml file.
      # @return [String] Path to the default batch config yaml file.
      def self.default_batch_config_path
        host_config = File.expand_path("#{CONFIG_ROOT}/#{Socket.gethostname}.yml")
        default_config = File.expand_path("#{CONFIG_ROOT}/batch.yml")
        File.file?(host_config) ? host_config : default_config
      end

      # Path to the batch config yaml file describing the batch servers for
      # local batch schedulers.
      # @return [String] Path to the batch config yaml file.
      def self.batch_config_path
        @batch_config_path ||= default_batch_config_path
      end

      # Set the path to the batch config yaml file.
      # @param path [String] The path to the batch config yaml file.
      def self.batch_config_path=(path)
        @batch_config_path = File.expand_path(path)
      end

      # Hash generated from reading the batch config yaml file.
      # @return [Hash] Batch configuration generated from config yaml file.
      def self.batch_config
        YAML.load_file(batch_config_path)
      end
  end
end

require_relative 'reservations/adapters/osc_moab'
