module OSC
  module Reservations
    # Batch server that utilizes reservations in the batch scheduler.
    class Batch
      # @return [String] the batch server to connect to.
      attr_reader :server

      # @param server [String] The server to connect to.
      # @param context [Hash] An optional hash of values that may be required by chosen adapter.
      def initialize(server, context = {})
        @server = server

        # symbolize keys
        @context = {}
        context.each do |key, value|
          @context[key.to_sym] = value
        end
      end

      # See if the method call exists as a key in @context.
      #
      # @param method_name the method name called
      # @param arguments the arguments to the call
      # @param block an optional block for the call
      def method_missing(method_name, *arguments, &block)
        @context.fetch(method_name) { super }
      end

      # Checks if the method responds to an instance method, or is able to
      # proxy it to @context.
      #
      # @param method_name the method name to check
      # @return [Boolean]
      def respond_to_missing?(method_name, include_private = false)
        @context.include?(method_name) || super
      end
    end
  end
end
