module OSC
  module Reservations
    # Provides a way for the developer to view the properties of any given
    # reserved node.
    class Node
      # @return [String] The ID of this node.
      attr_accessor :id

      # @return [Fixnum] Number of cores on this node.
      attr_accessor :np

      # @return [Array<String>] A list of properties for this node.
      attr_accessor :props

      # @return [Array<String>] A list of job id's running on this node.
      attr_accessor :jobs

      # @return [Array<String>] A list of users running on this node.
      attr_accessor :users

      # @param opts [Hash] Options used to create a node.
      # @option opts [String] :id The ID of this node.
      # @option opts [Fixnum] :np The number of processors on this node.
      # @option opts [Array<String>] :props An array of properties for this node.
      # @option opts [Array<String>] :jobs An array of job IDs running on this node.
      # @option opts [Array<String>] :users An array of users running on this node.
      def initialize(opts)
        @id    = opts[:id]
        @np    = opts[:np]
        @props = opts[:props]
        @jobs  = opts[:jobs]
        @users = opts[:users]
      end

      # Is this node free to use?
      # @return [Boolean] is node free?
      def free?
        jobs.empty?
      end
    end
  end
end
